Class: Pulse::ConditionalWrapper

Inherits:
Component
  • Object
show all
Defined in:
app/components/pulse/conditional_wrapper.rb

Overview

Conditionally renders a BaseComponent around the given content. If the given condition is true, a BaseComponent will render around the content. If the condition is false, only the content is rendered.

Instance Method Summary collapse

Constructor Details

#initialize(condition:, **base_component_arguments) ⇒ ConditionalWrapper

Returns a new instance of ConditionalWrapper.

Parameters:

  • condition (Boolean)

    Whether or not to wrap the content in a BaseComponent.

  • base_component_arguments (Hash)

    The arguments to pass to BaseComponent.



10
11
12
13
# File 'app/components/pulse/conditional_wrapper.rb', line 10

def initialize(condition:, **base_component_arguments)
  @condition = condition
  @base_component_arguments = base_component_arguments
end

Instance Method Details

#callObject



15
16
17
18
19
# File 'app/components/pulse/conditional_wrapper.rb', line 15

def call
  return content unless @condition

  BaseComponent.new(**@base_component_arguments).render_in(self) { content }
end